@@ -1731,27 +1731,6 @@ def gaussian(x, amp, mean, sigma, offset):
 	"""
 	return amp * np.exp(-1.0 * ((x-mean)/sigma)**2.0) + offset
 
-#functions for fitting to a gaussian
-def fitFunction(xdata, ydata, function = None, bounds = None, p0 = None):
-	popt = None
-	pcov = None
-	if function is None:
-		function = gaussian
-	try:
-		if bounds is None and p0 is None:
-			popt, pcov = curve_fit(function, xdata, ydata)
-		elif bounds is not None and p0 is None:
-			popt, pcov = curve_fit(function, xdata, ydata, bounds = bounds)
-		elif bounds is None and p0 is not None:
-			popt, pcov = curve_fit(function, xdata, ydata, p0=p0)
-		elif bounds is not None and p0 is not None:
-			popt, pcov = curve_fit(function, xdata, ydata, p0=p0, bounds = bounds)
-	except Exception as e: 
-		print('Fitting Failed:', e)
-		return None, None
-	return popt, pcov
-
-
 @numba.jit
 def expFit(x, amp, decay1, offset):
 	"""
